@@ -93,7 +93,7 @@ class line(plot):
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
-                 font='serif', math_font="dejavuserif", font_color="black", font_size_increase=0,
+                 font='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axis
                  fig=None, ax=None, figsize=(5, 4), shape_and_position=111, azim=-138, elev=19, remove_axis=None,
                  # Setup
@@ -119,7 +119,7 @@ class line(plot):
                  # Grid
                  grid=True, grid_color='lightgrey', grid_lines='-.',
                  # Title
-                 title=None, title_weight='normal', title_size=12, title_y=1.025, title_color=None, title_font=None,
+                 title=None, title_weight='normal', title_size=12, title_y=1.025, title_color=None, title_font='Latin Modern Roman',
                  # Labels
                  label_x='x', label_weight_x='normal', label_size_x=12, label_pad_x=7, label_rotation_x=None,
                  label_y='y', label_weight_y='normal', label_size_y=12, label_pad_y=7, label_rotation_y=None,
@@ -227,7 +227,7 @@ class scatter(plot):
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
-                 font='serif', math_font="dejavuserif", font_color="black", font_size_increase=0,
+                 font='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axis
                  fig=None, ax=None, figsize=(5, 4), shape_and_position=111, azim=-138, elev=19, remove_axis=None,
                  # Setup
@@ -253,7 +253,7 @@ class scatter(plot):
                  # Grid
                  grid=True, grid_color='lightgrey', grid_lines='-.',
                  # Title
-                 title=None, title_weight='normal', title_size=12, title_y=1.025, title_color=None, title_font=None,
+                 title=None, title_weight='normal', title_size=12, title_y=1.025, title_color=None, title_font='Latin Modern Roman',
                  # Labels
                  label_x='x', label_weight_x='normal', label_size_x=12, label_pad_x=7, label_rotation_x=None,
                  label_y='y', label_weight_y='normal', label_size_y=12, label_pad_y=7, label_rotation_y=None,
@@ -374,7 +374,7 @@ class surface(plot):
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
-                 font='serif', math_font="dejavuserif", font_color="black", font_size_increase=0,
+                 font='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axis
                  fig=None, ax=None, figsize=(5, 4), shape_and_position=111, azim=-138, elev=19, remove_axis=None,
                  # Setup
@@ -400,7 +400,7 @@ class surface(plot):
                  # Grid
                  grid=True, grid_color='lightgrey', grid_lines='-.',
                  # Title
-                 title=None, title_weight='normal', title_size=12, title_y=1.025, title_color=None, title_font=None,
+                 title=None, title_weight='normal', title_size=12, title_y=1.025, title_color=None, title_font='Latin Modern Roman',
                  # Labels
                  label_x='x', label_weight_x='normal', label_size_x=12, label_pad_x=7, label_rotation_x=None,
                  label_y='y', label_weight_y='normal', label_size_y=12, label_pad_y=7, label_rotation_y=None,
