@@ -97,7 +97,7 @@ class line(plot):
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
-                 font='serif', math_font="dejavuserif", font_color="black", font_size_increase=0,
+                 font='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axes
                  fig=None, ax=None, figsize=None, shape_and_position=111, resize_axes=True,
                  scale=None, aspect=1,
@@ -118,7 +118,7 @@ class line(plot):
                  # Grid
                  grid=True, grid_color='lightgrey', grid_lines='-.',
                  # Title
-                 title=None, title_size=12, title_pad=10, title_weight=None, title_font=None, title_color=None,
+                 title=None, title_size=17, title_pad=20, title_weight=None, title_font='Latin Modern Roman', title_color=None,
                  # Labels
                  label_x=None, label_size_x=12, label_pad_x=10, label_rotation_x=None, label_weight_x=None,
                  label_y=None, label_size_y=12, label_pad_y=10, label_rotation_y=None, label_weight_y=None,
@@ -245,7 +245,7 @@ class scatter(plot):
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
-                 font='serif', math_font="dejavuserif", font_color="black", font_size_increase=0,
+                 font='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axes
                  fig=None, ax=None, figsize=None, shape_and_position=111, resize_axes=True,
                  scale=None, aspect=1,
@@ -266,7 +266,7 @@ class scatter(plot):
                  # Grid
                  grid=True, grid_color='lightgrey', grid_lines='-.',
                  # Title
-                 title=None, title_size=12, title_pad=10, title_weight=None, title_font=None, title_color=None,
+                 title=None, title_size=17, title_pad=20, title_weight=None, title_font='Latin Modern Roman', title_color=None,
                  # Labels
                  label_x=None, label_size_x=12, label_pad_x=10, label_rotation_x=None, label_weight_x=None,
                  label_y=None, label_size_y=12, label_pad_y=10, label_rotation_y=None, label_weight_y=None,
@@ -382,7 +382,7 @@ class heatmap(plot):
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
-                 font='serif', math_font="dejavuserif", font_color="black", font_size_increase=0,
+                 font='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axes
                  fig=None, ax=None, figsize=None, shape_and_position=111, resize_axes=True,
                  scale=None, aspect=1,
@@ -403,7 +403,7 @@ class heatmap(plot):
                  # Grid
                  grid=True, grid_color='lightgrey', grid_lines='-.',
                  # Title
-                 title=None, title_size=12, title_pad=10, title_weight=None, title_font=None, title_color=None,
+                 title=None, title_size=17, title_pad=20, title_weight=None, title_font='Latin Modern Roman', title_color=None,
                  # Labels
                  label_x=None, label_size_x=12, label_pad_x=10, label_rotation_x=None, label_weight_x=None,
                  label_y=None, label_size_y=12, label_pad_y=10, label_rotation_y=None, label_weight_y=None,
@@ -516,7 +516,7 @@ class quiver(plot):
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
-                 font='serif', math_font="dejavuserif", font_color="black", font_size_increase=0,
+                 font='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axes
                  fig=None, ax=None, figsize=None, shape_and_position=111, resize_axes=True,
                  scale=None, aspect=1,
@@ -537,7 +537,7 @@ class quiver(plot):
                  # Grid
                  grid=True, grid_color='lightgrey', grid_lines='-.',
                  # Title
-                 title=None, title_size=12, title_pad=10, title_weight=None, title_font=None, title_color=None,
+                 title=None, title_size=17, title_pad=20, title_weight=None, title_font='Latin Modern Roman', title_color=None,
                  # Labels
                  label_x=None, label_size_x=12, label_pad_x=10, label_rotation_x=None, label_weight_x=None,
                  label_y=None, label_size_y=12, label_pad_y=10, label_rotation_y=None, label_weight_y=None,
@@ -681,7 +681,7 @@ class streamline(plot):
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
-                 font='serif', math_font="dejavuserif", font_color="black", font_size_increase=0,
+                 font='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axes
                  fig=None, ax=None, figsize=None, shape_and_position=111, resize_axes=True,
                  scale=None, aspect=1,
@@ -702,7 +702,7 @@ class streamline(plot):
                  # Grid
                  grid=True, grid_color='lightgrey', grid_lines='-.',
                  # Title
-                 title=None, title_size=12, title_pad=10, title_weight=None, title_font=None, title_color=None,
+                 title=None, title_size=17, title_pad=20, title_weight=None, title_font='Latin Modern Roman', title_color=None,
                  # Labels
                  label_x=None, label_size_x=12, label_pad_x=10, label_rotation_x=None, label_weight_x=None,
                  label_y=None, label_size_y=12, label_pad_y=10, label_rotation_y=None, label_weight_y=None,
@@ -831,7 +831,7 @@ class fill_area(plot):
                  # Backend
                  backend='Qt5Agg',
                  # Fonts
-                 font='serif', math_font="dejavuserif", font_color="black", font_size_increase=0,
+                 font='serif', font_math="dejavuserif", font_color="black", font_size_increase=0,
                  # Figure, axes
                  fig=None, ax=None, figsize=None, shape_and_position=111, resize_axes=True,
                  scale=None, aspect=1,
@@ -852,7 +852,7 @@ class fill_area(plot):
                  # Grid
                  grid=True, grid_color='lightgrey', grid_lines='-.',
                  # Title
-                 title=None, title_size=12, title_pad=10, title_weight=None, title_font=None, title_color=None,
+                 title=None, title_size=17, title_pad=20, title_weight=None, title_font='Latin Modern Roman', title_color=None,
                  # Labels
                  label_x=None, label_size_x=12, label_pad_x=10, label_rotation_x=None, label_weight_x=None,
                  label_y=None, label_size_y=12, label_pad_y=10, label_rotation_y=None, label_weight_y=None,
